% Script that shows the results of the fitting

% Optimal fitting parameters previously found
parDICtoTheory = par_opt;

% SIFs and T-STRESS
T_fitting = 4*parDICtoTheory(2);
KI_fitting = meanKI; 
KII_fitting = meanKII;

% Printing the results
fprintf('KI_fitting = %4.2f\n',KI_fitting);
fprintf('KII_fitting = %4.2f\n',KII_fitting);
% fprintf('T_fitting = %4.2f\n\n',T_fitting);


% Construction of a grid (G = grid) to show the theoretical model. 
% The grid is in the same spatial window as the DIC data.
limX_DIC = [min(xyzDICnew1(:,1)), max(xyzDICnew1(:,1))];
limY_DIC = [min(xyzDICnew1(:,2)), max(xyzDICnew1(:,2))];
xG = limX_DIC(1):0.05:limX_DIC(2);
yG = limY_DIC(1):0.05:limY_DIC(2);
[XG, YG] = meshgrid(xG,yG);
matxyG = zeros(size(XG,1)*size(XG,2),2);
ind = 0;
for i = 1:size(XG,1)
    for j = 1:size(XG,2)
        ind = ind +1;
        matxyG(ind,:) = [XG(i,j) YG(i,j)];
    end
end
matxyG_rot = [matxyG(:,1)*cos(alpha_r)-matxyG(:,2)*sin(alpha_r), matxyG(:,1)*sin(alpha_r)+matxyG(:,2)*cos(alpha_r)];

% Computing the y-displacement of the points of the grid
uY_theory = WilliamModel(matxyG_rot,parDICtoTheory);
xyz_theory = [matxyG_rot,uY_theory];
ptCloud_theory = pointCloud(xyz_theory);

% Computing the difference between DIC and the theoretical model
uY_theoryDICgrid = WilliamModel(xyzDICnew2(:,1:2),parDICtoTheory);
xyz_theoryDICgrid = [xyzDICnew2(:,1:2),uY_theoryDICgrid];
ptCloud_theoryDICgrid = pointCloud(xyz_theoryDICgrid);
Zdif = (xyzDICnew2(:,3) - uY_theoryDICgrid);
cut = 0.010; 
Zdif(Zdif > cut| Zdif < -cut) = NaN; % Filter for outliers
xyz_dif = [xyzDICnew2(:,1:2), Zdif];
ptCloud_diff = pointCloud(xyz_dif);


%-------------------------------------------------------------------------%
%                          RESULTS VISUALIZATION
%-------------------------------------------------------------------------%

% Theoretical model
figure
pcshow(ptCloud_theory, 'MarkerSize', 70);
hold on
plot(0,0,'go','LineWidth',3);
daspect([max(daspect)*[1 1] scale_v]) 
c1 = colorbar;
c1.Label.String = 'v [mm]';
c1.Label.FontWeight = 'bold';
c1.Limits = [-0.05 0.05];
xlabel('X [mm]');
ylabel('Y [mm]');
title('Theory');
colormap(gca,'jet')
view(0,90)
set(gca,'fontsize',10);
set(gca,'FontWeight','bold');
set(gca,'LineWidth',1.5);
set(gca,'TickLength',[0.018, 0.018]);


% DIC results
ptCloudDICnew = pointCloud(xyzDICnew2);
figure
pcshow(ptCloudDICnew, 'MarkerSize', 70)
hold on
plot(0,0,'go','LineWidth',3);
daspect([max(daspect)*[1 1] scale_v]) 
c1 = colorbar;
c1.Label.String = 'v [mm]';
c1.Label.FontWeight = 'bold';
c1.Limits = [-0.05 0.05];
xlabel('X [mm]');
ylabel('Y [mm]');
title('DIC')
colormap(gca,'jet')
view(0,90)
set(gca,'fontsize',10);
set(gca,'FontWeight','bold');
set(gca,'LineWidth',1.5);
set(gca,'TickLength',[0.018, 0.018]);


% Difference
figure
pcshow(ptCloud_diff, 'MarkerSize', 70)
hold on
daspect([max(daspect)*[1 1] scale_v]) 
c1 = colorbar;
c1.Label.String = '\Deltav [mm]';
c1.Label.FontWeight = 'bold';
% c1.Limits = [-0.0005 0.0005];
xlabel('X [mm]');
ylabel('Y [mm]');
title('DIC - Theory')
colormap(gca,'jet')
view(0,90)
set(gca,'fontsize',10);
set(gca,'FontWeight','bold');
set(gca,'LineWidth',1.5);
set(gca,'TickLength',[0.018, 0.018]);


% DIC & Theory 3D Comparison
figure
show2Mats(xyzDICnew2, xyz_theory, [1 0 0], [0 0 1], scale_v);
%legend('DIC','Theory')
%title('DIC and Theory')
set(gca,'fontsize',10);
set(gca,'FontWeight','bold');
set(gca,'LineWidth',1.5);